@@ -904,7 +904,7 @@ class CameraDevice(Protocol):
 
     def get_capabilities(self) -> list[CameraDeviceCapability]: ...
     def has_capability(self, capability: CameraDeviceCapability) -> bool: ...
-    async def add_capabilities(self, capabilities: list[CameraDeviceCapability]) -> None: ...
+    def add_capabilities(self, capabilities: list[CameraDeviceCapability]) -> None: ...
 
 
 CameraSelectedCallback = Union[
